$TITLE GTAP data v10 2014 to Global SAM with Satellite Data
* Elasticities, TS Trade and Energy
$OFFUPPER
$ONEMPTY

*############## 1. GENERAL NOTES ON USING GTAP DATA ######################
$ontext
  THIS PROGRAMME - glbsam10_2014.gms IS SET UP FOR GTAP V10 for 2014
  THE ASSOCIATED EXCEL FILE IS data_glbsam_10_2014.xlsx

*############### WARNING #################
  GTAP often makes seemingly minor changes to labels and names used for
  parameters between releases. Many of these are irrelevant to users of
  GEMPACK but can cause issues for GAMS users.

  For each new version of the GTAP database it is often necessary to
 'adjust' the programme and Excel workbook. Hence the many checks in this
  programme.

  PLEASE NOTE: WE KEEP MANY CHECKS IN THIS PROGRAMME TO ALLOW FOR CHECKING
               WITH THE EVOLUTION OF THE GTAP DATABASE. THIS IS
               DELIBERATE AND WE WILL CONTINUE TO DO SO.

  We are not board members so can only produce a new version when we get
  access to new versions of the database. GTAP will not support making
  these codes available to modellers wishing to use GAMS.

  This version last checked 30 Sept 2019

  If you have any suggestions as to how we could improve this programme
  we will be grateful to receive samples of code.

$offtext

*############## 1. GENERAL NOTES ON USING GTAP DATA ######################

$ontext

Developed by Scott McDonald (Humboldt University of Berlin)
             Karen Thierfelder (US Naval Academy)

       Scott McDonald                      Karen Thierfelder
       International Agricultural
          Trade and Development Group      Dept of Economics
       Humboldt-University of Berlin       US Naval Academy
       Unter den Linden 6                  Annapolis
       10099 Berlin, Germany               Maryland, USA
       email:                              email:
       jrs.mcdonald@gmail.com              thier@usna.edu
       scott@cgemod.org.uk                 karen@cgemod.org.uk

Copyright (c) 2019 Scott McDonald and Karen Thierfelder

  This code is provided in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
FOR A PARTICULAR PURPOSE.

  If you are using this programme you should acknowledge the source and
not claim authorship.

  Altered versions must be clearly distinguished from the original.

  If you find these conditions unacceptable you should delete the code and
all related files from your PC, etc., immediately and no copy should be kept.

$offtext

$INCLUDE include\gtap_data_notes.inc

*############## 2. OUTLINE OF PROGRAMME ################################
$ontext
  3.  PROGRAMME DESCRIPTION
  4.  CONVERT GTAP DATA TO GDX
  5.  DEFINING ELEMENTS OF THIS PROGRAMME THAT RUN
  6.  DECLARING AND ASSIGNING SETS FOR THIS PROGRAMME
  7.  DECLARING, ASSIGNING AND CHECKING THE GTAP SAM
  8.  DECLARING PARAMETERS FOR OTHER GTAP DATA
  9.  DECLARING AND ASSIGNING GLOBE SAM TRANSACTIONS
  10. DERIVING GTAP SALES TAXES AND IMPLIED VAT
  11. ADDITIONAL DATA FROM GTAP
  12. UNLOAD GTAP SAM and SATELLITE ACCOUNTS
  13. VARIOUS SAMS FOR USE BY GLOBE MODELS

$offtext

*############## TO DO ON THIS VERSION #############################
$ontext

 1.  Extend summary statistics about TVs in BASIC global SAM - SAMG
 2.  Review trade error counts
 4.  Generalise the treatment of inbalances in the margins
 5.  Code for GLOBE 3 and GLOBE t
 6.  Check description file
 7.  Execute_Unload 'GTP_data_in_GDX.gdx' needs to use append
 8.  Review "gtap_data_notes.inc"
 9.  Review "gtpsam_descrip.inc"

$offtext

*############## 3. PROGRAMME DESCRIPTION ##################################

$INCLUDE include\gtpsam_descrip.inc

*############## 4. CONVERT GTAP DATA TO GDX ##############################
$ontext
 Data are rendered readable by GAMS using HAR2GDX

 IDEALLY, the GTAP sets data could be used to reduce the amount of data
   read in from Excel, BUT GTAP sets data use the SAME labels for some
   regions and sectors. This can cause ordering problems in GAMS so it
   is less error prone to define many of the sets and maps in Excel

NB After the first time this programme is run the HAR2GDX CALL statements
    SHOULD be turned off since the gdx versions have been written to disk.

$offtext

* Converting the GTAP SAM data to GDX
$CALL har2gdx  data\GTAPsam.har     data\GTAPsam.gdx
$CALL har2gdx  Sets.har             sets.gdx

* Converting the other GTAP data to GDX
$CALL har2gdx  data\basedata.har    data\basedata.gdx

* Converting Excel sets data to GDX
$CALL "GDXXRW i=data_glbsam_10_2014.xlsx o=data_in.gdx INDEX=LAYOUT!A4 trace=3"
$if errorLevel 1 $abort problems with GDXXRW


*############## 5. DEFINING ELEMENTS OF THIS PROGRAMME THAT RUM #######
$ontext

 This section uses the ASK utility to impose USER defined preferences

   1.  The extent to which the TVs in the GTAP database are truncated:
        Options are: 0 - truncated at millions of $USD (no decimal places)
                     1 - truncated at '00,000 of $USD (1 decimal place)
                     2 - truncated at '0,000 of $USD (2 decimal place)
                     3 - truncated at '000 of $USD (3 decimal place)
                     4 - truncated at '00 of $USD (4 decimal place)
                     5 - truncated at '0 of $USD (5 decimal place)
                     6 - truncated at $USD (6 decimal place)

   2.  The GLOBE model versions of the GTAP SAMs
        Options are: GLOBE 1 SAM
                     GLOBE 1 En(ergy) SAM
                     GLOBE 2 SAM
                     GLOBE 2 En(ergy) SAM

        AND various combinations.

$offtext

$INCLUDE include\glbsam_ask.inc

*############## 6. DECLARING AND ASSIGNING SETS FOR THIS PROGRAMME #######
$ontext
   This section declares and assigns all the sets used to process the GTAP
 data.
   Where possible these are taken from GTAP's HAR files and/or 'hard' coded,
 BUT set ordering is an issue when using GAMS and hence it is often more
 efficient to record the sets in Excel; the order in which sets are loaded
 is critical.

$offtext

$INCLUDE include\gtpsam_sets.inc

*############## 7. DECLARING, ASSIGNING AND CHECKING THE GTAP SAM #######

$ontext

  The SAM from GTAPAgg is used to initialise the BASIC global SAM, SAMG,
    that is the basis for all subsequent developments.

  The transactions in SAMG are the same as those in the SAM from GTAPAgg, BUT
    the account labels have been modified to better meet subsequent
    requirements.

  The SAM from GTAPAgg is deleted in this section, i.e., will not be
    reported in the GDX dump triggered by the command line gdx=*** statement.

  At the end of this section the BASIC global SAM, SAMG, is unloaded to GDX
    as samg_gtp.gdx, together with calculations about the differences
    in row and column totals: this should be checked to make sure that no
    MAJOR differences exist

  This section also derives a series of summary statistics about the
    transactions reported in SAMG: Max and Min Transaction Values (TV) by
    region - TO BE EXTENDED

$offtext

$INCLUDE include\gtpsam_SAMG_gtp.inc


*############## 8. DECLARING PARAMETERS FOR OTHER GTAP DATA #######
$ontext
 The other parameters used for GTAP data are declared here.

 They are only assigned when needed; use a REFERENCE FILE to find assignment
    statements.

$offtext

$INCLUDE include\gtp_parm.inc

*############## 9. DECLARING AND ASSIGNING GLOBE SAM TRANSACTIONS #######

$ontext
  This file does the following
 1. glbsam_make.inc - This file
     a.  create SAMG,
     b.  segments ad valorem and specific sales taxes,
     c.  clears out certain GTAP labels,
     d.  removes the REGIONAL HOUSEHOLD construct, and
     e.  adds estimates of the internal balance (government saving/borrowing)
         and uses those estimates to derive estimates of household savings

          At the end of this section the BASIC GLOBE SAM, SAMG, is
          unloaded to GDX as stats\SAMG_basic.gdx, together with calculations
          about the differences in row and column totals: this should be
          checked to make sure that no MAJOR differences exist
$offtext

$INCLUDE include\glbsam_make.inc

$ontext

 SAMG_test is only a partial test; in particular specific tariffs are not
 recorded in SAMG_gtp.

 Its main use is to help identify mismatching of sets.

$offtext

Parameter
 SAMG_test(ss,ss,kk)   Test of SAMG_basic and SAM_gtp ;

 SAMG_test(ss,ssp,kk) = SAMG(ss,ssp,kk) - SAMG_gtp(ss,ssp,kk) ;


$ontext
  This file does the following
 2. glbsam_trunc.inc
     a.  truncates the GTAP data at a USER specified number of decimal
         places,
     b.  deletes any taxes and margins that are levied on zero
         transactions, and
     c.  deletes activities that have 'undesirable' characteritics
          i.   employ capital but no labour,
          ii.  employ labour but no capital,
          iii. produce output less than 10**(-(dec_num-1))

          At the end of this section the TRUNCATED GLOBE SAM, SAMG, is
          unloaded to GDX as stats\SAMG_make.gdx, together with calculations
          about the differences in row and column totals: this should be
          checked to make sure that no MAJOR differences exist
$offtext

$INCLUDE include\glbsam_trunc.inc

$ontext
  This file does the following
 3. glbsam_glo.inc - introduces and populates the GLOBE region with margins
      trade data, adjusts the region SAMs to the presence of the GLOBE region

          At the end of this section the GLOBE SAM cw the GLOBE region,
          SAMG, is unloaded to GDX as stats\SAMG_trunc.gdx, together with
          calculations about the differences in row and column totals:
          this should be checked to make sure that no MAJOR differences exist
$offtext

$INCLUDE include\glbsam_glo.inc

$ontext
  This file does the following
 4. glbsam_bal.inc - manually balances the SAMG to achieve equality in the
      row and column totals. The USER needs to ensure that the previous
      steps have implemented correctly; if they are completed correctly
      all imbalances are due to
      (a) imbalances in the base GTAP data,
      (b) imbalances created by the truncation process, and
      (c) imbalances due to removing taxes and margins on NOW zero
          transactions.

          At the end of this section the GLOBE SAM cw the GLOBE region,
          SAMG, is unloaded to GDX as stats/SAMG_balanced.gdx, together with
          calculations about the differences in row and column totals:
          this should be checked to make sure that no MAJOR differences exist
$offtext

$INCLUDE include\glbsam_bal.inc

*############## 10. DERIVING GTAP SALES TAXES AND IMPLIED VAT #######

$ontext
  The file in this section does the following
 1. glbsam_saltax.inc - derives estimates of the sales tax rates in the
      TRUNCATED GTAP database. The results are exported to GDX as
      'gtp_saltax_rates.gdx'
          It is valuable to review the 'sales' tax rates in the GTAP
          database so as to understand the implications of the
          subsequent adjustments.

$offtext

$INCLUDE include\glbsam_saltax.inc


*############## 11. ADDITIONAL DATA FROM GTAP ########################

$INCLUDE include\gtp_basedata.inc

*############## 12. UNLOAD GTAP SAM and SATELLITE ACCOUNTS ###########
$ontext
  The data unloaded here are the truncated GTAP SAM and ALL satellite account
  data as rendered into GDX format.

  All the set labels are as in the GTAP SAM

  The GTAP SAM has been truncated and balanced according to the user defined
  number of decimal places. The balancing is done manually to avoid
  any data points being smaller than defined by the user. The method alos
  avoids and substantive changes in policy instruments.

  The data have been checked to remove any tax or margin payments on
  transactions that have gone to ZERO in the truncation process.

  All satellite account data have been checked to remove any energy use and/or
  emmisions on transactions that have gone to ZERO in the truncation process

$offtext
Execute_Unload 'GTP_output\gtp_data_10_14.gdx',
* Accounts set
 ss
* Truncated and Balanced SAM in GTAP structure
 SAMG
* Factor based
 FacSubs
 FacEmpTax
* Activity based
 OutSubs
* Intermediate Input based
 IntInSubsM
 IntInSubsD
* Export based
 MFASubs
 OrdXSub
* Import based
 OrdMDuty
*#### DOMESTIC SALES
 TVOM2
*#### POPULATION DATA
 POP
*#### CAPITAL STOCK DATA
 Kstoc
*#### GTAP ELASTICITIES DATA
* Satellite account data
 ESUBVA
 ESUBD
 ESUBM
 SUBCDE
 INCCDE
 ESUBT
 ETRAE
 RFLX
*#### GTAP ENERGY DATA
* SAM Satelitte Data
 EVolD
 EVolM
 EVolT
*#### GTAP EMISSIONS DATA
* SAM Satelitte Data
 Em_D_C02
 Em_M_C02
* ImpactEcon LABOUR DATA
* SAM Satelitte Data
 Q_FD
 Q_FS

 ;


*############## 13. VARIOUS SAMS FOR USE BY GLOBE MODELS #######

$ontext

 The various SAMs for the GLOBE model are ALL labelled SAMG and are ONLY
 differentiated by the naming of the GDX files.
     This is to make using the aggregation programmes easier

  The files in this section do the following

 1. glbsam_GLB3.inc - derives the database for GLOBE 3

 2. glbsam_GLB2.inc - derives the database for GLOBE 2

 3. glbsam_GLB2_EN.inc - derives  the database for GLOBE 2 Energy

 4. glbsam_GLB1.inc - derives the database for GLOBE 1

 5. glbsam_GLB1_EN.inc - derives the database for GLOBE 1 Energy

$offtext

Parameter

 SAMG_B(ss,ss,kk)      Base version of SAMG

* Temporary versions of the GLOBE SAMS

 SAMG_2(ss,ss,kk)      SAMG for GLB2
 SAMG_2_en(ss,ss,kk)   SAMG for GLB2 energy
 SAMG_1(ss,ss,kk)      SAMG for GLB1
 SAMG_1_en(ss,ss,kk)   SAMG for GLB1 energy


* Satellite accounts
 ESUBDC(cc)          Armington CES for domestic_imported allocation
 ESUBMC(cc)          Armington CES for regional allocation of imports

 ;

* Initilising SAMG_B

 SAMG_B(ss,ssp,kk)  =  SAMG(ss,ssp,kk) ;

* Clearing out SAMG

 SAMG(ss,ssp,kk)    = 0.0 ;

*$INCLUDE glbsam_GLB3.inc

IF(glb_sams = 1,

$INCLUDE include\glbsam_GLB2.inc

 )
 ;

IF(glb_sams = 2,

$INCLUDE include\glbsam_GLB2_EN.inc

 )
 ;

IF(glb_sams = 3,

$INCLUDE include\glbsam_GLB2.inc
$INCLUDE include\glbsam_GLB2_EN.inc

 )
 ;

IF(glb_sams = 4,

$INCLUDE include\glbsam_GLB2.inc

 )
 ;

IF(glb_sams = 5,

$INCLUDE include\glbsam_GLB2_EN.inc

 )
 ;

IF(glb_sams = 6,

$INCLUDE include\glbsam_GLB1.inc
$INCLUDE include\glbsam_GLB1_EN.inc

 )
 ;

IF(glb_sams = 7,

$INCLUDE include\glbsam_GLB1.inc
$INCLUDE include\glbsam_GLB1_EN.inc

$INCLUDE include\glbsam_GLB2.inc
$INCLUDE include\glbsam_GLB2_EN.inc

 )
 ;


*########################### THE END ########################
