$TITLE GTAP data v9.1 2011 to Global SAM with Satellite Data
* Elasticities, TS Trade and Energy
$OFFUPPER
$ONEMPTY

*############## 1. GENERAL NOTES ON USING GTAP DATA ######################

$INCLUDE include\gtap_data_notes.inc

*############## 2. OUTLINE OF PROGRAMME ################################
$ontext
  3.  PROGRAMME DESCRIPTION
  4.  CONVERT GTAP DATA TO GDX
  5.  DEFINING ELEMENTS OF THIS PROGRAMME THAT RUN
  6.  DECLARING AND ASSIGNING SETS FOR THIS PROGRAMME
  7.  DECLARING, ASSIGNING AND CHECKING THE GTAP SAM
  8.  DECLARING PARAMETERS FOR OTHER GTAP DATA
  9.  DECLARING AND ASSIGNING GLOBE SAM TRANSACTIONS
  10. DERIVING GTAP SALES TAXES AND IMPLIED VAT
  11. ADDITIONAL DATA FROM GTAP
  12. UNLOAD GTAP SAM and SATELLITE ACCOUNTS
  13. VARIOUS SAMS FOR USE BY GLOBE MODELS

$offtext

*############## TO DO ON THIS VERSION #############################
$ontext

 1.  Extend summary statistics about TVs in BASIC global SAM - SAMG
 2.  Review trade error counts
 3.  Sort out an issue with DIFPER
 4.  Generalise the treatment of inbalances in the margins
 5.  Code for GLOBE 3
 6.  Check description file
 7.  Execute_Unload 'GTP_data_in_GDX.gdx' needs to use append

$offtext

*############## 3. PROGRAMME DESCRIPTION ##################################

$INCLUDE include\gtpsam_descrip.inc

*############## 4. CONVERT GTAP DATA TO GDX ##############################
$ontext
 Data are rendered readable by GAMS using HAR2GDX

 IDEALLY, the GTAP sets data could be used to reduce the amount of data
   read in from Excel, BUT GTAP sets data use the SAME labels for some
   regions and sectors. This can cause ordering problems in GAMS so it
   is less error prone to define many of the sets and maps in Excel

NB After the first time this programme is run the HAR2GDX CALL statements
    SHOULD be turned off since the gdx versions have been written to disk.

$offtext

* Converting the GTAP SAM data to GDX
$CALL har2gdx  data\GTAPsam.har     data\GTAPsam.gdx
*$CALL har2gdx   Sets.har        sets.gdx

* Converting the other GTAP data to GDX
$CALL har2gdx   data\basedata.har    data\basedata.gdx

* Converting Excel sets data to GDX
$CALL "GDXXRW i=data_glbsam_9_1_11.xlsx o=data_in.gdx INDEX=LAYOUT!A4 trace=3"
$if errorLevel 1 $abort problems with GDXXRW


*############## 5. DEFINING ELEMENTS OF THIS PROGRAMME THAT RUN #######
$ontext

 This section uses the ASK utility to impose USER defined preferences

   1.  The extent to which the TVs in the GTAP database are truncated:
        Options are: 0 - truncated at millions of $USD (no decimal places)
                     1 - truncated at '00,000 of $USD (1 decimal place)
                     2 - truncated at '0,000 of $USD (2 decimal place)
                     3 - truncated at '000 of $USD (3 decimal place)
                     4 - truncated at '00 of $USD (4 decimal place)
                     5 - truncated at '0 of $USD (5 decimal place)
                     6 - truncated at $USD (6 decimal place)

   2.  The GLOBE model versions of the GTAP SAMs
        Options are: GLOBE 1 SAM
                     GLOBE 1 En(ergy) SAM
                     GLOBE 2 SAM
                     GLOBE 2 En(ergy) SAM

        AND various combinations.

$offtext

$INCLUDE include\glbsam_ask.inc


*############## 6. DECLARING AND ASSIGNING SETS FOR THIS PROGRAMME #######
$ontext
   This section declares and assigns all the sets used to process the GTAP
 data.
   Where possible these are taken from GTAP's HAR files and/or 'hard' coded,
 BUT set ordering is an issue when using GAMS and hence it is often more
 efficient to record the sets in Excel; the order in which sets are loaded
 is critical.

$offtext

$INCLUDE include\gtpsam_sets.inc

*############## 7. DECLARING, ASSIGNING AND CHECKING THE GTAP SAM #######

$ontext

  The SAM from GTAPAgg is used to initialise the BASIC global SAM, SAMG,
    that is the basis for all subsequent developments.

  The transactions in SAMG are the same as those in the SAM from GTAPAgg, BUT
    the account labels have been modified to better meet subsequent
    requirements.

  The SAM from GTAPAgg is deleted in this section, i.e., will not be
    reported in the GDX dump triggered by the command line gdx=*** statement.

  At the end of this section the BASIC global SAM, SAMG, is unloaded to GDX
    as samg_gtp.gdx.

  This section also derives a series of summary statistics about the
    transactions reported in SAMG: Max and Min Transaction Values (TV) by
    region - TO BE EXTENDED

$offtext

$INCLUDE include\gtpsam_SAMG_gtp.inc


*############## 8. DECLARING PARAMETERS FOR OTHER GTAP DATA #######
$ontext
 The other parameters used for GTAP data are declared here.

 They are only assigned when needed; use a REFERENCE FILE to find assignment
    statements.

$offtext

$INCLUDE include\gtp_parm.inc

*############## 9. DECLARING AND ASSIGNING GLOBE SAM TRANSACTIONS #######

$ontext
  The files in this section do the following
 1. glbsam_make.inc - creates SAMG and segments ad valorem and specific
      sales taxes. This file also clears out certain GTAP labels and
      removes the REGIONAL HOUSEHOLD construct.

 2.  glbsam_trunc.inc - truncates the GTAP data at a USER specified
      number of decimal places and deletes any taxes and margins that
      are levied on zero transactions

 3.  glbsam_glo.inc - introduces and populates the GLOBE region with
      margins trade data, adjusts the region SAMs to the presence of
      the GLOBE region

 4. glbsam_bal.inc - manually balances the SAMG to achieve equlity in
      the row and column totals. The USER needs to ensure that the
      previous steps have implemented correctly; if that is the cases
      that ALL imbalances are due to (a) imbalances in the base GTAP
      data, (b) imbalances created by the truncation process and
     (c) imbalances due to removing taxes and margins on NOW zero
      transactions.

$offtext


$INCLUDE include\glbsam_make.inc

$INCLUDE include\glbsam_trunc.inc

$INCLUDE include\glbsam_glo.inc

$INCLUDE include\glbsam_bal.inc

*############## 10. DERIVING GTAP SALES TAXES AND IMPLIED VAT #######

$ontext
  The file in this section does the following
 1. glbsam_saltax.inc - derives estimates of the sales tax rates in the
      TRUNCATED GTAP database. The results are exported to GDX as
      'gtp_saltax_rates.gdx'
          It is valuable to review the 'sales' tax rates in the GTAP
          database so as to undertand the implications of the
          subsequent adjustments.

$offtext

$INCLUDE include\glbsam_saltax.inc


*############## 11. ADDITIONAL DATA FROM GTAP ########################

$INCLUDE include\gtp_basedata.inc

*############## 12. UNLOAD GTAP SAM and SATELLITE ACCOUNTS ###########
$ontext
  The data unloaded here are the truncated GTAP SAM and ALL satellite
  account data as rendered into GDX format.

  All the set labels are as in the GTAP SAM

  The GTAP SAM has been truncated and balanced according to the user defined
  number of decimal places. The balancing is done manually so as to avoid
  any data points being smaller than defined by the user.

  The data have been checked to remove any tax or margin payments on
  transactions that have gone to ZERO in the truncation process.

  All satellite account data have been checked to remove any energy use
  and/or emmisions on transactions that have gone to ZERO in the
  truncation process

$offtext

Execute_Unload 'GTP_output\gtp_data_9_1_11.gdx',
* Truncated and Balanced SAM in GTAP structure
 SAMG
* Factor based
 FacSubs
 FacEmpTax
* Activity based
 OutSubs
* Intermediate Input based
 IntInSubsM
 IntInSubsD
* Export based
 MFASubs
 OrdXSub
* Import based
 OrdMDuty
*#### DOMESTIC SALES
 TVOM2
*#### POPULATION DATA
 POP
*#### CAPITAL STOCK DATA
 Kstoc
*#### GTAP ELASTICITIES DATA
* Satellite account data
 ESUBVA
 ESUBD
 ESUBM
 SUBCDE
 INCCDE
 ESUBT
 ETRAE
 RFLX
*#### GTAP ENERGY DATA
* SAM Satelitte Data
 EVolD
 EVolM
 EVolT
*#### GTAP EMISSIONS DATA
* SAM Satelitte Data
 Em_D_C02
 Em_M_C02

* ImpactEcon LABOUR DATA
* SAM Satelitte Data
 Q_FD
 Q_FS

 ;

*############## 13. VARIOUS SAMS FOR USE BY GLOBE MODELS #######

$ontext

 The various SAMs for the GLOBE model are ALL labelled SAMG and are ONLY
 differentiated by the naming of the GDX files.
     This is to make using the aggregation programmes easier

  The files in this section do the following

 1. glbsam_GLB3.inc - derives the database for GLOBE 3

 2. glbsam_GLB2.inc - derives the database for GLOBE 2

 3. glbsam_GLB2_EN.inc - derives  the database for GLOBE 2 Energy

 4. glbsam_GLB1.inc - derives the database for GLOBE 1

 5. glbsam_GLB1_EN.inc - derives the database for GLOBE 1 Energy

$offtext

Parameter

 SAMG_B(ss,ss,kk)      Base version of SAMG

* Temporary versions of the GLOBE SAMS

 SAMG_2(ss,ss,kk)      SAMG for GLB2
 SAMG_2_en(ss,ss,kk)   SAMG for GLB2 energy
 SAMG_1(ss,ss,kk)      SAMG for GLB1
 SAMG_1_en(ss,ss,kk)   SAMG for GLB1 energy


* Satellite accounts
 ESUBDC(cc)          Armington CES for domestic_imported allocation
 ESUBMC(cc)          Armington CES for regional allocation of imports

 ;

* Initilising SAMG_B

 SAMG_B(ss,ssp,kk)  =  SAMG(ss,ssp,kk) ;

* Clearing out SAMG

 SAMG(ss,ssp,kk)    = 0.0 ;

* Satellite accounts converted to aggregate commodities

 ESUBDC(cc)        = SUM(mmc
                       $map_cc_mmc(cc,mmc),
                       ESUBD(mmc)) ;

 ESUBMC(cc)        = SUM(mmc
                       $map_cc_mmc(cc,mmc),
                       ESUBM(mmc)) ;

* This IF produces NO GLOBE SAMs
IF(glb_sams = 0,

 )
 ;

* This IF produces GLOBE 2 SAM
IF(glb_sams = 1,

$INCLUDE include\glbsam_GLB2.inc

 )
 ;

* This IF produces GLOBE 2 Energy SAM
IF(glb_sams = 2,

$INCLUDE include\glbsam_GLB2_EN.inc

 )
 ;

* This IF produces GLOBE 2 Standard and Energy SAMs
IF(glb_sams = 3,

$INCLUDE include\glbsam_GLB2.inc
$INCLUDE include\glbsam_GLB2_EN.inc

 )
 ;

* This IF produces GLOBE 1 SAM
IF(glb_sams = 4,

$INCLUDE include\glbsam_GLB1.inc

 )
 ;

* This IF produces GLOBE 1 Energy SAM
IF(glb_sams = 5,

$INCLUDE include\glbsam_GLB1_EN.inc

 )
 ;

* This IF produces GLOBE 1 Standard and Energy SAMs
IF(glb_sams = 6,

$INCLUDE include\glbsam_GLB1.inc
$INCLUDE include\glbsam_GLB1_EN.inc

 )
 ;

* This IF produces GLOBE 1 and 2 Standard and Energy SAMs
IF(glb_sams = 7,

$INCLUDE include\glbsam_GLB1.inc
$INCLUDE include\glbsam_GLB1_EN.inc

$INCLUDE include\glbsam_GLB2.inc
$INCLUDE include\glbsam_GLB2_EN.inc

 )
 ;


*########################### THE END ########################

