$Title Aggregation Programme for GTAP Database SAMs
$ONSYMLIST ONSYMXREF OFFUPPER
$ONEMPTY

*Generated at 05/11/2019 17:59:02 for scott by Aggr.xls


$ontext

This version
Scott McDonald
cgemod.org.uk
Last modified: Feb 2019

Original version
Scott McDonald
Dept of Economics, University of Sheffield
Aug 2005

This programme aggregates a SAM representation of GTAP version 9.2 for GLB2

This file has been generated with sets and mappings defined for a specific aggregation.

Input and Ouput are via GDX

$offtext

*########## SETGLOBAL TO CONTROL DATA AND SET INPUT #################
$ontext

 SETGLOBAL allows for string substitutions

Format is

 keyword   varname   text

then when compiling the text is substituted for the varname

$offtext

$SETGLOBAL data_input       glb_samg_v2

$SETGLOBAL sets_input       globagg_10_GAMS_example

*###################### SET DECLARATION #############################


* read in sets for base data

SETS

      ss              SAM accounts

      cc(ss)          Composite Commodities

      aa(ss)          Activities

      ff(ss)          Factors

      ttm(ss)         Ad valorem import duties
      ttms(ss)        Specific import duties
      tte(ss)         Export taxes
      tts(ss)         Taxes on Commodities
      ttff(ss)        Taxes on Factors

      ootpm(ss)       Other trade and transport costs
      wwtpm(ss)       Water trade and transport costs
      aatpm(ss)       Air trade and transport costs
      vvst(ss)        Exports of trade and transport services

      ww(ss)          Rest of the World

      ii(ss)          Investment

      kk              Regions

* Declaring SETS that will be assigned from the data


* Declaring other sets

      ssn(ss)         SAM accounts excluding TOTAL
      row(ss)         SAM accounts excluding TOTAL


  ;

* Setting up ALIASES

 ALIAS(ss,ssp) ;
 ALIAS(ssn,ssnp) ;
 ALIAS(cc,ccp) ;
 ALIAS(aa,aap) ;
 ALIAS(ff,ffp,ENDOW_COMM) ;
 ALIAS(ttm,ttmp) ;
 ALIAS(ttms,ttmsp) ;
 ALIAS(tte,ttep) ;
 ALIAS(tts,ttsp) ;
 ALIAS(ttff,ttffp) ;
 ALIAS(ootpm,ootpmp) ;
 ALIAS(wwtpm,wwtpmp) ;
 ALIAS(aatpm,aatpmp) ;
 ALIAS(vvst,VVSTP) ;
 ALIAS(ww,wwp) ;
 ALIAS(kk,kkp,REGP) ;
 ALIAS(row,coll) ;


*## Global SAM sets are defined here

$INCLUDE gtp_sets.inc


* Defining SETS by exclusions from previously defined SETS

* SAM Accounts excluding totals
 ssn(ss)        = YES ;
 SSN("ttotal")  = NO ;

 row(ss)        = YES ;
 row("ttotal")  = NO ;




DISPLAY ss, cc, aa, ff,
        ttm, ttms, tte, ttff,
        ootpm, wwtpm,aatpm, vvst,
        ww, ii, kk
    ;


* Output set declarations and definitions

SETS
 s           New SAM accounts

 c(s)        Composite Commodities
 a(s)        Activities
 f(s)        Factors
 tmr(s)      Import taxes
 tmrs(s)     Specific Import Taxes
 ter(s)      Export taxes
 tss(s)      Taxes on Commodities
 tff(s)      Taxes on Factors
 w(s)        Rest of the World

* margin sets
 otpmarg(s)    OTHER margins on imports
 wtpmarg(s)    WATER margins on imports
 atpmarg(s)    AIR margins on imports
 owtpmarg(s)   OTHER and WATER margins on imports
 oatpmarg(s)   OTHER and AIR margins on imports
 watpmarg(s)   WATER and AIR margins on imports
 owatpmarg(s)  all margins on imports


 k            New SAM Regions

* Mapping set for aggregation
 mapsamag(s,ss)   Mapping from ss to s

 mapregag(k,kk)   SAMG Region mapping to New SAM

 ;



*#### LOADING DEFINTIONS FROM EXCEL

$CALL "GDXXRW i=%sets_input%.xlsx o=data_in.gdx index=Layout!A4 trace=3"
$if errorLevel 1 $abort problems with GDXXRW

$GDXIN data_in.gdx

$LOADdc s
$LOADdc c a f tmr tmrs ter tss tff w
$LOADdc otpmarg wtpmarg atpmarg owtpmarg oatpmarg watpmarg owatpmarg

$LOADdc k

$LOAD mapsamag mapregag

$GDXIN

*### ALIASES common to All Aggregation Levels #####

ALIAS(ss, ssp) ;
ALIAS(s,sp,spp) ;
ALIAS(f,fp,fpp) ;


* Checks that each ss and kk are only mapped to one s and k

Parameter
 chk_mapsamag(ss)         Checking on mapping to s from ss
 chk_mapregag(kk)         Checking on mapping to k from kk

 ;

 chk_mapsamag(ss)     = SUM[s$mapsamag(s,ss), 1] ;
 loop(ss,
  ABORT$(chk_mapsamag(ss) gt 1)
   "## Error in chk_mapsamag. Account allocated to more than one aggregate ##",
   chk_mapsamag ;
*End loop
 ) ;

 chk_mapregag(kk)   = SUM[k$mapregag(k,kk), 1] ;
 loop(kk,
  ABORT$(chk_mapregag(kk) gt 1)
   "## Error in chk_mapregag. Account allocated to more than one aggregate ##",
   chk_mapregag ;
*End loop
 ) ;


*################## DATA ENTRY ####################################

 PARAMETERS

 SAMG(ss,ssp,kk)   Social accounting matrices for regions k

;

* Data are read in from a *.gdx file

$GDXIN 1_data\%data_input%.gdx

$LOADdc SAMG = SAMG

$GDXIN

*DISPLAY SAMG ;

*################### SAM AGGREGATION ############################

PARAMETER
   NEWSAM(sp,spp,k)          Aggregate SAM derived
   SUMROW(sp,k)              Row sum parameter by region
   SUMCOL(sp,k)              Column sum parameter by region
   SAMCHECK(sp,k)            Check on account totals parameter by region ;



*######### AGGREGATION ASSIGNMENT #######################

 NEWSAM(sp,spp,k)           = SUM((ss,ssp,kk)
                                $(MAPSAMAG(sp,ss)
                                $MAPSAMAG(spp,ssp)
                                $MAPREGAG(k,kk)),
                                SAMG(ss,ssp,kk)) ;


*#### Rounding the New SAM to 6 Decimal Places
* The GTAP database only records data to 6 decimal places

 NEWSAM(sp,spp,k)      = ROUND(NEWSAM(sp,spp,k),6) ;



*COMPUTE TOTALS AND CHECK

 NEWSAM(sp,"TOTAL",k)   = 0.0 ;
 NEWSAM("TOTAL",sp,k)   = 0.0 ;

 NEWSAM(sp,"TOTAL",k)   = SUM(spp, NEWSAM(sp,spp,k)) ;
 NEWSAM("TOTAL",spp,k)  = SUM(sp, NEWSAM(sp,spp,k)) ;

 SUMROW(sp,k)           = NEWSAM(sp,"TOTAL",k) ;
 SUMROW(sp,k)           = ROUND(SUMROW(sp,k),6) ;

 SUMCOL(spp,k)          = NEWSAM("TOTAL",spp,k) ;
 SUMCOL(spp,k)          = ROUND(SUMCOL(spp,k),6) ;

 SAMCHECK(sp,k)         = SUMROW(sp,k) - SUMCOL(sp,k) ;
 SAMCHECK(sp,k)         = ROUND(SAMCHECK(sp,k),6) ;


DISPLAY NEWSAM, SAMCHECK ;

*#################### ELASTICITIES ####################

SET
      kk2(kk)         SET KK less glo
       k2(k)           SET K less glb

 ;

 kk2(kk)        = YES ;
 kk2("glo")     = NO ;

 k2(k)          = YES ;
 k2("glb")      = NO ;


PARAMETER

 ESUBVA(ss)         CES between primary factors in production
 ESUBD(ss)          Armington CES for domestic_imported allocation
 ESUBM(ss)          Armington CES for regional allocation of imports

 WESUBD(ss,k)       weights on Armington domestic_imported allocation
 DOMSUPP(ss,k)      domestic supply
 WESUBDCHK(k)       CHECK weights on Armington domestic_imported allocation

 ESUBD2(s,k)        FINAL Armington CES for domestic_imported allocation

 WESUBM_pwm(ss,k)   weights on Armington regional allocation of imports
 WESUBM_pwmchk(k)   CHK weights on Armington regional allocation of imports

 ESUBM2(s,k)        FINAL Armington CES for regional allocation of imports
 ESUBM3(s,k)        ALT_FINAL Armington CES for regional allocation of imports

 WESUBVA(ss,k)      weights on CES between primary factors in prodn
 WESUBVACHK(k)      CHK weights on CES between primary factors in prodn

 ESUBVA2(s,k)       FINAL CES between primary factors in production

   ;

* Loading parameters

$GDXIN 1_data\%data_input%.gdx

$LOADdc ESUBVA = ESUBVA
$LOADdc ESUBD  = ESUBD
$LOADdc ESUBM  = ESUBM

$GDXIN

DISPLAY ESUBVA, ESUBD, ESUBM ;

*##### ESUBD
* Weights on ESUBD

 DOMSUPP(cc,k) = SUM(kk$MAPREGAG(k,kk),(SAMG(cc,"ttotal",kk)
                   - SUM(ww,SAMG(cc,ww,kk))
                   - SUM(vvst,SAMG(cc,vvst,kk)))) ;

 WESUBD(cc,k)  = (SUM(kk$MAPREGAG(k,kk),SAMG(cc,"ttotal",kk)) + DOMSUPP(cc,k))
                     /SUM(ccp,(SUM(kk$MAPREGAG(k,kk),SAMG(ccp,"ttotal",kk)) + DOMSUPP(ccp,k))) ;

 WESUBDCHK(k)  = SUM(cc,WESUBD(cc,k)) ;


* Weighted Average Elasticities

 ESUBD2(s,k)$(k2(k) AND SUM(ssp$MAPSAMAG(s, ssp),WESUBD(ssp,k)))
                    = SUM(ss$MAPSAMAG(s, ss), (ESUBD(ss)
                            * WESUBD(ss,k)))
                           /SUM(ssp$MAPSAMAG(s, ssp),WESUBD(ssp,k)) ;

*##### ESUBM
* Weights on ESUBM

 WESUBM_pwm(cc,k)   = SUM(kk$MAPREGAG(k,kk),(SUM(ww,SAMG(ww,cc,kk))
                      + SUM(ootpm,SAMG(ootpm,cc,kk))
                      + SUM(wwtpm,SAMG(wwtpm,cc,kk))
                      + SUM(aatpm,SAMG(aatpm,cc,kk))))
                         /SUM(kk$MAPREGAG(k,kk),(SUM((ww,ccp),SAMG(ww,ccp,kk))
                           + SUM((ootpm,ccp),SAMG(ootpm,ccp,kk))
                           + SUM((wwtpm,ccp),SAMG(wwtpm,ccp,kk))
                           + SUM((aatpm,ccp),SAMG(aatpm,ccp,kk))))  ;

 WESUBM_pwmchk(k)   = SUM(cc,WESUBM_pwm(cc,k)) ;

* Weighted Average Elasticities

 ESUBM2(s,k)$(k2(k) AND SUM(ssp$MAPSAMAG(s, ssp),WESUBM_pwm(ssp,k)))
                    = SUM(ss$MAPSAMAG(s, ss), (ESUBM(ss)
                            * WESUBM_pwm(ss,k)))
                           /SUM(ssp$MAPSAMAG(s, ssp),WESUBM_pwm(ssp,k)) ;

* Weights are the same as for ESUD2 for ESUBM3

 ESUBM3(s,k)$(k2(k) AND SUM(ssp$MAPSAMAG(s, ssp),WESUBD(ssp,k)))
                    = SUM(ss$MAPSAMAG(s, ss), (ESUBM(ss)
                            * WESUBD(ss,k)))
                           /SUM(ssp$MAPSAMAG(s, ssp),WESUBD(ssp,k)) ;

Parameter
 TEST2(c,k)   test on elasticities
 TEST3(c,k)   test on elasticities  ;

 TEST2(c,k)$(k2(k) AND ESUBM2(c,k))  = ESUBD2(c,k)/ESUBM2(c,k) ;
 TEST3(c,k)$(k2(k) AND ESUBM3(c,k))  = ESUBD2(c,k)/ESUBM3(c,k) ;

DISPLAY TEST2, TEST3 ;

*##### ESUBVA
* Weights on ESUBVA

 WESUBVA(aa,k)$k2(k)
                 = SUM(kk$MAPREGAG(k,kk),SUM(ff,SAMG(ff,aa,kk)))
                   /SUM(kk$MAPREGAG(k,kk),SUM((ff,aap),SAMG(ff,aap,kk))) ;

 WESUBVACHK(k)   = SUM(aa,WESUBVA(aa,k)) ;

* Weighted Average Elasticities

 ESUBVA2(s,k)$(k2(k) AND SUM(ssp$MAPSAMAG(s, ssp),WESUBVA(ssp,k)))
                    = SUM(ss$MAPSAMAG(s, ss), (ESUBVA(ss)
                            * WESUBVA(ss,k)))
                           /SUM(ssp$MAPSAMAG(s, ssp),WESUBVA(ssp,k)) ;

DISPLAY DOMSUPP, WESUBD, WESUBDCHK, ESUBD2,
        WESUBM_pwm, WESUBM_pwmchk, ESUBM2,
        WESUBVA, WESUBVACHK, ESUBVA2 ;


*#################### LABOUR QUANTITY DATA ####################

Parameter
 FACTUSE1(ss,ss,kk)    Factor quantity data from IMPACTEcon
 FACTUSE(s,s,k)        Factor quantity data for model
 ;

* Loading parameters

$GDXIN 1_data\%data_input%.gdx

$LOAD FACTUSE1 = FACTUSE

$GDXIN

 FACTUSE(sp,spp,k)           = SUM((ss,ssp,kk)
                                $(MAPSAMAG(sp,ss)
                                $MAPSAMAG(spp,ssp)
                                $MAPREGAG(k,kk)),
                                FACTUSE1(ss,ssp,kk)) ;

Display FACTUSE ;

*#################### CAPITAL STOCK DATA ####################

PARAMETER

 Kstoc(kk)          Capital Stock data from GTAP

 fsk(k)             Aggregated capital stcoks
   ;

* Loading parameters

$GDXIN 1_data\%data_input%.gdx

$LOAD Kstoc = Kstoc

$GDXIN

DISPLAY Kstoc ;

 fsk(k)       = SUM(kk$mapregag(k,kk), Kstoc(kk)) ;

DISPLAY fsk ;

*#################### POPULATION DATA ####################

PARAMETER

 POPn(kk)          Population data from GTAP

 pop(k)            Aggregated aggregated population stcoks
   ;

* Loading parameters

$GDXIN 1_data\%data_input%.gdx

$LOAD POPn = POP

$GDXIN

DISPLAY POPn ;

 pop(k)       = SUM(kk$mapregag(k,kk), POPn(kk)) ;

DISPLAY pop ;

*#################### EXPORT OF RESULT FILES ####################

*#######  Export new aggregation to GDX ###################

*## Writing out the NEW SAMs to GDX

* This writes all the SAM data to GDX

* NB THE COMMON COMPONENT AT THE BOTTOM TO UNLOAD SETS TO GDX


Execute_Unload  '2_output\data_output.gdx',
* Aggregate SAM
NEWSAM
* Aggregate FACTUSE
FACTUSE
* Aggregated GTAP Elasticities
ESUBD2
ESUBM2
ESUBM3
ESUBVA2
* Aggregate capital stocks
fsk
* Aggregated populations
pop
* common instruction for unloading sets to GDX
s
c
a
f
tmr
tmrs
ter
tss
tff
w
owatpmarg
K

     ;

*###### COMPILING THE MODEL WORKBOOK ###################

Alias(k,kp,r) ;

*---- Creating additional sets for GLOBE model workbook

Set
 fagg   Aggregate labour /
 flab
 /

 ct(c)   Margin commodities
 h(s)    Households
 g(s)    Government accouts
 i(s)    Investment accounts

 map_fag_f(fagg,f)  maps fagg f
 map_ct_w(c,w)      maps ct to w

 ;

 h("hous")    = YES ;

 g("saltax")  = YES ;
 g("vattax")  = YES ;
 g("prodtax") = YES ;
 g("dirtax")  = YES ;
 g("govt")    = YES ;

 i("i_s")     = YES ;
 i("dstoc")   = YES ;

 ct(c)$SUM(r,NEWSAM(c,"wglb",r))  = YES ;

 map_fag_f(fagg,f) = YES ;
 map_ct_w(ct,w)    = YES ;

Display fagg, ct, h, g, i, map_fag_f, map_ct_w ;

*---- Creating elasticity parameters for GLOBE model workbook

Parameter
 elaste(c,k)      Domestic export elasticities
 elastre(c,k)     Export by region elasticities

 elastx(a,k)      VA intermediate elasticities

 elastfd(fagg,a,k)   Labour sub elasticities

 frisch(k,s)      Frisch parameters
 elasty(c,s,k)    Household income elasticities

 ue_rate(k,f)     Unemployment rate

 ;

 elaste(c,k)         = 0.5 ;
 elastre(c,k)        = 1.5 ;

 elastx(a,k)         = 0.5 ;

 elastfd(fagg,a,k)   = 3.0 ;

 frisch(k,h)         = - 1.0 ;
 elasty(c,h,k)       = 1.0 ;

 ue_rate(k,f)        = EPS ;

*---- Creating additional sets for writing out details to Excel

Sets
* These sets are only used for writing out details to Excel
s_x       SAM Accounts
c_x
a_x
ff_x
f_x
tmr_x
tmrs_x
ter_x
tss_x
tff_x
w_x
owatpmarg_x

k_x

 ;

s_x(s)          = YES ;
s_x(fagg)       = YES ;

c_x(c)          = YES ;
a_x(a)          = YES ;

f_x(f)          = YES ;
ff_x(f)         = YES ;
ff_x(fagg)      = YES ;

tmr_x(tmr)      = YES ;
tmrs_x(tmrs)    = YES ;
ter_x(ter)      = YES ;
tss_x(tss)      = YES ;
tff_x(tff)      = YES ;

w_x(w)          = YES ;

owatpmarg_x(owatpmarg)      = YES ;

k_x(k)          = YES ;

*#################### EXPORT ADDITIONAL DATA ####################

Execute_Unload  '1_data\temp_data.gdx',
* Sets
 fagg
 h
 g
 i
* Pseudo Elasticities
 elaste
 elastre
 elastx
 elastfd
 frisch
 elasty
* Unemployment rate
 ue_rate

* Aggregate SAM
NEWSAM
* Aggregated GTAP Elasticities
ESUBD2
ESUBM2
ESUBM3
ESUBVA2
* Aggregate capital stocks
fsk
* Aggregated populations
pop
* common instruction for unloading sets to GDX
s
c
ct
a
f
tmr
tmrs
ter
tss
tff
w
owatpmarg
K

s_x
c_x
a_x
ff_x
f_x
tmr_x
tmrs_x
ter_x
tss_x
tff_x
w_x
owatpmarg_x

k_x

map_fag_f
map_ct_w

     ;


* Writing out the sets
* SAM set
Execute "GDXXRW i=1_data\temp_data.gdx o=2_output\data_C_F_R.xlsx set=s_x Rng=sets!A5 rdim=1"
Execute "GDXXRW i=1_data\temp_data.gdx o=2_output\data_C_F_R.xlsx set=s Rng=sets!A5 rdim=1"
* region set
Execute "GDXXRW i=1_data\temp_data.gdx o=2_output\data_C_F_R.xlsx set=k Rng=sets!D5 rdim=1"

* reference set
Execute "GDXXRW i=1_data\temp_data.gdx o=2_output\data_C_F_R.xlsx set=k_x Rng=sets!G5 rdim=1"

* SAM major sub sets
Execute "GDXXRW i=1_data\temp_data.gdx o=2_output\data_C_F_R.xlsx set=c_x Rng=sets!I5 rdim=1"
Execute "GDXXRW i=1_data\temp_data.gdx o=2_output\data_C_F_R.xlsx set=a_x Rng=sets!Q5 rdim=1"
Execute "GDXXRW i=1_data\temp_data.gdx o=2_output\data_C_F_R.xlsx set=ff_x Rng=sets!Y5 rdim=1"
Execute "GDXXRW i=1_data\temp_data.gdx o=2_output\data_C_F_R.xlsx set=f_x Rng=sets!Z5 rdim=1"
Execute "GDXXRW i=1_data\temp_data.gdx o=2_output\data_C_F_R.xlsx set=fagg Rng=sets!AG5 rdim=1"
Execute "GDXXRW i=1_data\temp_data.gdx o=2_output\data_C_F_R.xlsx set=h Rng=sets!AH5 rdim=1"
Execute "GDXXRW i=1_data\temp_data.gdx o=2_output\data_C_F_R.xlsx set=tmr_x Rng=sets!AI5 rdim=1"
Execute "GDXXRW i=1_data\temp_data.gdx o=2_output\data_C_F_R.xlsx set=tmrs_x Rng=sets!AJ5 rdim=1"
Execute "GDXXRW i=1_data\temp_data.gdx o=2_output\data_C_F_R.xlsx set=ter_x Rng=sets!AK5 rdim=1"
Execute "GDXXRW i=1_data\temp_data.gdx o=2_output\data_C_F_R.xlsx set=tss_x Rng=sets!AL5 rdim=1"
Execute "GDXXRW i=1_data\temp_data.gdx o=2_output\data_C_F_R.xlsx set=tff_x Rng=sets!AM5 rdim=1"
Execute "GDXXRW i=1_data\temp_data.gdx o=2_output\data_C_F_R.xlsx set=g Rng=sets!AN5 rdim=1"
Execute "GDXXRW i=1_data\temp_data.gdx o=2_output\data_C_F_R.xlsx set=i Rng=sets!AO5 rdim=1"
Execute "GDXXRW i=1_data\temp_data.gdx o=2_output\data_C_F_R.xlsx set=owatpmarg_x Rng=sets!AP5 rdim=1"
Execute "GDXXRW i=1_data\temp_data.gdx o=2_output\data_C_F_R.xlsx set=w_x Rng=sets!AQ5 rdim=1"
Execute "GDXXRW i=1_data\temp_data.gdx o=2_output\data_C_F_R.xlsx set=w_x Rng=sets!AS5 rdim=1"
Execute "GDXXRW i=1_data\temp_data.gdx o=2_output\data_C_F_R.xlsx set=k_x Rng=sets!AT5 rdim=1"

* Partial write outs
* map_c_w_marg
Execute "GDXXRW i=1_data\temp_data.gdx o=2_output\data_C_F_R.xlsx set=map_ct_w Rng=maps!A5 rdim=2"
Execute "GDXXRW i=1_data\temp_data.gdx o=2_output\data_C_F_R.xlsx set=owatpmarg_x Rng=maps!C5 rdim=1"

* map_wagg_w
Execute "GDXXRW i=1_data\temp_data.gdx o=2_output\data_C_F_R.xlsx set=w_x Rng=maps!E5 rdim=1"
Execute "GDXXRW i=1_data\temp_data.gdx o=2_output\data_C_F_R.xlsx set=w_x Rng=maps!F5 rdim=1"

* map_ragg_r
Execute "GDXXRW i=1_data\temp_data.gdx o=2_output\data_C_F_R.xlsx set=k_x Rng=maps!H5 rdim=1"
Execute "GDXXRW i=1_data\temp_data.gdx o=2_output\data_C_F_R.xlsx set=k_x Rng=maps!I5 rdim=1"

* map_fag_f
Execute "GDXXRW i=1_data\temp_data.gdx o=2_output\data_C_F_R.xlsx set=map_fag_f Rng=maps!K5 rdim=2"

*~~~~~~ Writing out the elasticities derived from GTAP

* Factor Substitution Elasticities
Execute "GDXXRW i=1_data\temp_data.gdx o=2_output\data_C_F_R.xlsx par=ESUBVA2 Rng=actelastva!B5 rdim=1 cdim=1"
* CES elasticities between domestic and imported
Execute "GDXXRW i=1_data\temp_data.gdx o=2_output\data_C_F_R.xlsx par=ESUBD2 Rng=comelastm!B5 rdim=1 cdim=1"
* CES elasticities between imports by source regions
Execute "GDXXRW i=1_data\temp_data.gdx o=2_output\data_C_F_R.xlsx par=ESUBM2 Rng=comelastrm!B5 rdim=1 cdim=1"

*~~~~~~ Writing out MEANINGLESS elasticities TO DIMEMSION the workbook
* Export CET elasticities
Execute "GDXXRW i=1_data\temp_data.gdx o=2_output\data_C_F_R.xlsx par=elaste Rng=comelaste!B5 rdim=1 cdim=1"
Execute "GDXXRW i=1_data\temp_data.gdx o=2_output\data_C_F_R.xlsx par=elastre Rng=comelastre!B5 rdim=1 cdim=1"
* Production elasticities
Execute "GDXXRW i=1_data\temp_data.gdx o=2_output\data_C_F_R.xlsx par=elastx Rng=actelastx!B5 rdim=1 cdim=1"
Execute "GDXXRW i=1_data\temp_data.gdx o=2_output\data_C_F_R.xlsx par=elastfd Rng=actelastfd!B5 rdim=2 cdim=1"
* LES elasticities
Execute "GDXXRW i=1_data\temp_data.gdx o=2_output\data_C_F_R.xlsx par=frisch Rng=frischelast!B5 rdim=1 cdim=1"
Execute "GDXXRW i=1_data\temp_data.gdx o=2_output\data_C_F_R.xlsx par=elasty Rng=incelast!B5 rdim=2 cdim=1"

*~~~~~~ Writing out Default Unemployment rates
Execute "GDXXRW i=1_data\temp_data.gdx o=2_output\data_C_F_R.xlsx par=ue_rate Rng=unemp_rate!B5 rdim=1 cdim=1"


*############################## THE END ############################


