*--- Introducing the globe region for margins

option decimals = 6 ;
*---- Populating the SAM for globe

Parameter
 SAM_glo(ss,ss)         SAM for globe

 marg_exps(ss,kk)       Margin exports of type ddc by region kk

 marg_imps(ss,kk)       Margin imports of type mmc by region kk

 marg_diff(ss)          Difference in Margin imports and exports by GLOBE

 scal_glb(ss)           Scaling factors margins imports by GLOBE

 ;

*--- Margin exports by globe (are imports o/w/atp by other regions kkn to wwglo)

* Margin Imports by Region

 marg_imps("mmotp",kkn)  = SUM((ootpm,mmc),SAMG(ootpm,mmc,kkn)) ;
 marg_imps("mmwtp",kkn)  = SUM((wwtpm,mmc),SAMG(wwtpm,mmc,kkn)) ;
 marg_imps("mmatp",kkn)  = SUM((aatpm,mmc),SAMG(aatpm,mmc,kkn)) ;

* Margin Exports by Region

 marg_exps("ddotp",kkn)  = SAMG("ddotp","ootppvst",kkn) ;
 marg_exps("ddwtp",kkn)  = SAMG("ddwtp","wwtppvst",kkn) ;
 marg_exps("ddatp",kkn)  = SAMG("ddatp","aatppvst",kkn) ;

 marg_diff("mmotp")      = SUM(kkn,marg_exps("ddotp",kkn)) - SUM(kkn,marg_imps("mmotp",kkn)) ;
 marg_diff("mmwtp")      = SUM(kkn,marg_exps("ddwtp",kkn)) - SUM(kkn,marg_imps("mmwtp",kkn)) ;
 marg_diff("mmatp")      = SUM(kkn,marg_exps("ddatp",kkn)) - SUM(kkn,marg_imps("mmatp",kkn)) ;

DISPLAY marg_imps, marg_exps, marg_diff ;

*#### Populating GLOBE for IMPORTS AND EXPORTS
*## Exports by GLOBE

 SAMG("ddotp",wwn,"glo")  = SUM(kkn$map_ww_kk(wwn,kkn),marg_imps("mmotp",kkn)) ;
 SAMG("ddwtp",wwn,"glo")  = SUM(kkn$map_ww_kk(wwn,kkn),marg_imps("mmwtp",kkn)) ;
 SAMG("ddatp",wwn,"glo")  = SUM(kkn$map_ww_kk(wwn,kkn),marg_imps("mmatp",kkn)) ;

*## Imports by GLOBE
*-- BASE Margin imports by globe (are exports ddc from other regions kkn to wwglo)

 SAMG(wwn,"mmotp","glo")  = SUM(kkn$map_ww_kk(wwn,kkn),marg_exps("ddotp",kkn)) ;
 SAMG(wwn,"mmwtp","glo")  = SUM(kkn$map_ww_kk(wwn,kkn),marg_exps("ddwtp",kkn)) ;
 SAMG(wwn,"mmatp","glo")  = SUM(kkn$map_ww_kk(wwn,kkn),marg_exps("ddatp",kkn)) ;

*--- Scaling factor for margins imports by GLOBE

 scal_glb("mmotp")       = SUM(kkn,marg_imps("mmotp",kkn))/SUM(kkn,marg_exps("ddotp",kkn)) ;
 scal_glb("mmwtp")       = SUM(kkn,marg_imps("mmwtp",kkn))/SUM(kkn,marg_exps("ddwtp",kkn)) ;
 scal_glb("mmatp")       = SUM(kkn,marg_imps("mmatp",kkn))/SUM(kkn,marg_exps("ddatp",kkn)) ;


 SAMG(wwn,"mmotp","glo")  = SAMG(wwn,"mmotp","glo") * scal_glb("mmotp") ;
 SAMG(wwn,"mmwtp","glo")  = SAMG(wwn,"mmwtp","glo") * scal_glb("mmwtp") ;
 SAMG(wwn,"mmatp","glo")  = SAMG(wwn,"mmatp","glo") * scal_glb("mmatp") ;

Parameter
 check_marg_bal(ss)     Check on equality of margin imports and exports by GLOBE
 ;

 check_marg_bal("ddotp")      = SUM(wwn,SAMG("ddotp",wwn,"glo")) - SUM(wwn,SAMG(wwn,"mmotp","glo")) ;
 check_marg_bal("ddwtp")      = SUM(wwn,SAMG("ddwtp",wwn,"glo")) - SUM(wwn,SAMG(wwn,"mmwtp","glo")) ;
 check_marg_bal("ddatp")      = SUM(wwn,SAMG("ddatp",wwn,"glo")) - SUM(wwn,SAMG(wwn,"mmatp","glo")) ;

Display scal_glb, check_marg_bal ;

* And TRUNCATING

 SAMG(wwn,mmc,"glo")  = trunc(SAMG(wwn,mmc,"glo")*trunc_fact) ;

 SAMG(wwn,mmc,"glo")  = SAMG(wwn,mmc,"glo")/trunc_fact ;

* Balancing after truncation

 check_marg_bal("mmotp")      = SUM(wwn,SAMG("ddotp",wwn,"glo")) - SUM(wwn,SAMG(wwn,"mmotp","glo")) ;
 check_marg_bal("mmwtp")      = SUM(wwn,SAMG("ddwtp",wwn,"glo")) - SUM(wwn,SAMG(wwn,"mmwtp","glo")) ;
 check_marg_bal("mmatp")      = SUM(wwn,SAMG("ddatp",wwn,"glo")) - SUM(wwn,SAMG(wwn,"mmatp","glo")) ;

Display check_marg_bal ;

 SAMG("wwkor","mmotp","glo")  = SAMG("wwkor","mmotp","glo") + check_marg_bal("mmotp") ;
 SAMG("wwkor","mmwtp","glo")  = SAMG("wwkor","mmwtp","glo") + check_marg_bal("mmwtp") ;
 SAMG("wwkor","mmatp","glo")  = SAMG("wwkor","mmatp","glo") + check_marg_bal("mmatp") ;

* Calculating trade balances for margins

 SAMG("ii_s",wwn,"glo") = SUM(mmc,SAMG(wwn,mmc,"glo"))
                           - SUM(ddc,SAMG(ddc,wwn,"glo")) ;

 SAMG("ii_s",vvst,kkn)  = 0.0 ;

 check_marg_bal("mmotp")      = SUM(wwn,SAMG("ddotp",wwn,"glo")) - SUM(wwn,SAMG(wwn,"mmotp","glo")) ;
 check_marg_bal("mmwtp")      = SUM(wwn,SAMG("ddwtp",wwn,"glo")) - SUM(wwn,SAMG(wwn,"mmwtp","glo")) ;
 check_marg_bal("mmatp")      = SUM(wwn,SAMG("ddatp",wwn,"glo")) - SUM(wwn,SAMG(wwn,"mmatp","glo")) ;

Display check_marg_bal ;

* Market clearing for commodity imports and exports by GLOBE

 SAMG("ddotp","mmotp","glo") = -1 * SUM(wwn,SAMG("ddotp",wwn,"glo")) ;
 SAMG("ddwtp","mmwtp","glo") = -1 * SUM(wwn,SAMG("ddwtp",wwn,"glo")) ;
 SAMG("ddatp","mmatp","glo") = -1 * SUM(wwn,SAMG("ddatp",wwn,"glo")) ;

*--- Computing the SAM for GLOBE

 SAM_glo(ss,ssp)        = SAMG(ss,ssp,"glo") ;

*###### Populating region data for transactions with GLOBE

* Exports for margin services to GLOBE by regions kkn

Parameter
 marg_exp_glb(ss,kk)   Margin exports by GLOBE
 ;

 marg_exp_glb("mmotp",kkn)  = SUM(wwn$map_kk_ww(kkn,wwn),SAMG(wwn,"mmotp","glo")) ;
 marg_exp_glb("mmwtp",kkn)  = SUM(wwn$map_kk_ww(kkn,wwn),SAMG(wwn,"mmwtp","glo")) ;
 marg_exp_glb("mmatp",kkn)  = SUM(wwn$map_kk_ww(kkn,wwn),SAMG(wwn,"mmatp","glo")) ;

 SAMG("ddotp","wwglo",kkn)  = marg_exp_glb("mmotp",kkn) ;
 SAMG("ddwtp","wwglo",kkn)  = marg_exp_glb("mmwtp",kkn) ;
 SAMG("ddatp","wwglo",kkn)  = marg_exp_glb("mmatp",kkn) ;

* Deleting elements in vvst
 SAMG("ddotp","ootppvst",kkn) = 0.0 ;
 SAMG("ddwtp","wwtppvst",kkn) = 0.0 ;
 SAMG("ddatp","aatppvst",kkn) = 0.0 ;

* Imports of margins servics by regions kkn from GLOBE

 SAMG("wwglo",ootpm,kkn)   = SUM(mmc,SAMG(ootpm,mmc,kkn)) ;
 SAMG("wwglo",wwtpm,kkn)   = SUM(mmc,SAMG(wwtpm,mmc,kkn)) ;
 SAMG("wwglo",aatpm,kkn)   = SUM(mmc,SAMG(aatpm,mmc,kkn)) ;

* Trade Balances with GLOBE for margin services

Parameter
 trad_bal_glo(ss)              GLOBE Trade balance
 trad_bal_glo2(kk)              GLOBE Trade balance

 ;

 trad_bal_glo(ww)       =  SAMG("ii_s",ww,"glo") ;

Display trad_bal_glo ;

 SAMG("ii_s","wwglo",kkn)  = SUM(wwn$map_kk_ww(kkn,wwn),trad_bal_glo(wwn)) ;


 trad_bal_glo2(kkn)      =SAMG("ii_s","wwglo",kkn) ;

Display trad_bal_glo, trad_bal_glo2 ;


*######## DELETING vvst Accounts

 SAMG(vvst,ss,kkn)         = 0.0 ;
 SAMG(ss,vvst,kkn)         = 0.0 ;

Parameter
 diff_SAM_glo(ss)    differences in SAM_glo row and column totals
 ;

 diff_SAM_glo(ssn)  = SAM_glo("ttotal",ssn) - SAM_glo(ssn,"ttotal") ;


Execute_unload 'stats\samg_glo1.gdx', SAM_glo
                                      marg_imps,
                                      marg_exps,
                                      marg_diff
 ;

*---- Removing the 'Errors' in Margins

* Recomputing the account totals

 SAMG("TTOTAL",ssnp,kk)        = SUM(ssn,SAMG(ssn,ssnp,kk)) ;
 SAMG(ssn,"TTOTAL",kk)         = SUM(ssnp,SAMG(ssn,ssnp,kk)) ;

$INCLUDE include\chk_samg.inc

Display "END of glbsam_glo" ;