*############## 1. GENERAL NOTES ON USING GTAP DATA ######################
$ontext

     WE STRONGLY RECOMMEND USING
       'rf=ref gdx=input cerr=10' or something equivalent
     in the GAMS command line.


 1.  The GTAP database is CONSISTENT, i.e, the row and column totals
     equate and each income to each agent is matched with an expenditure
     by an agent, but INCOMPLETE, i.e., there are missing transactions,
     e.g., current account transactions other than imports and exports
     of goods and services.
        This requires that 'some' transactions for every region must
        have been distorted to make the database CONSISTENT.

 2.  IDEALLY, the GTAP sets data could be used to reduce the amount of
     data read in from Excel, BUT GTAP sets data use the SAME labels
     for some regions and sectors. This can cause ordering problems in
     GAMS so it is less error prone to define many of the sets and
     maps in Excel.
       It has been indicated that GTAP may change its labels as some point
       in the future

 3.  Data are rendered readable by GAMS using HAR2GDX. After the first
     time this programme is run the HAR2GDX CALL statements CAN be
     turned off since the gdx versions will have been written to disk.

 4.  The transaction values (TV) in GTAP are reported in millions of US
     dollars to SIX decimal places, i.e., GTAP reports TV with an
     IMPLIED accuracy of a single US dollar. BUT this is not a
     correct interpretation.


 5.  In the GTAP database ALL TVs in ALL 'active' sub matrices, i.e.,
     sub matrices for which the GTAP model has behavioural relationships
     MUST have NON ZERO values. This is (apparently) because
       a.  the GTAP CGE model is implemented in GEMPACK,
       b.  the database is estimated using the FIT programme that uses
           GEMPACK, and
       c.  GEMPACK is single precision and uses log differences.

     This has some non trivial implications for users of the data
       a.  the database has a large number of datapoints that are
           NON ZERO, but do not represent real economic transactions,
           i.e., transactions that should be zero ('non zero zeros'),
       b.  it is not, apparently, possible to determine which NON ZERO
           transactions are in fact 'non zero zeros' (I gave up
           asking after 10 years and realising that FIT was a
           GEMPACK programme),
       c.  given the presence of 'non zero zeros' it is reasonable to
           conclude that some apparent TVs should be ignored from an
           economic perspective, while from a software, e.g., GAMS,
           perspective these very small TVs may be an 'inconvenience',
       c.  in the GTAP database as a SAM the row and column totals are
           not identical, which restricts the ability to use accounting
           identities to check the database without adjustments,
       d.  as the number of sectors, factor and regions in the GTAP
           database increases so the data problems presented by
           'non zero zeros' increase,
       e.  The GTAP 9.1 database contains a very large number of 'small'
           transactions.
           There are 4,580,307 datapoints in active sub matrices of the
           GTAP SAM, of which
               4,278,532 are transactions of greater than $(USD)1,
               3,830,984 are transactions of greater than $(USD)10,
               3,201,405 are transactions of greater than $(USD)100,
               2,444,050 are transactions of greater than $(USD)1,000
               1,66,791 are transactions of greater than $(USD)10,000,
               980,814 are transactions of greater than $(USD)100,000
       f.  the definition of a 'small' transaction is not the same for the
           USA as for, say, Mauritius,
       g.  the scale of transactions varies enormously, e.g., in GTAP 9.1
           for 2011 the largest transaction for the region with the
           smallest 'largest' transaction, 'Rest of the World' (xtw),
           is $102.434 m, while the largest transaction for the region
           with the largest 'largest' transaction, 'USA' (usa),
           is $10,887,626.000 m

  6.  The routines in this programme do NOT include provisions to augment
      the GTAP database. This means that some changes to the GTAP
      database are approximations; this is particularly the case with
      the removal of the REGIONAL HOUSEHOLD construct used in the
      GTAP database.

  7.  The routines in this programme include checks at each stage of
      the process, hence there are a very large number of checks.
      This reflects the experience that for each release of the GTAP
      database it has been necessary to identify release specific
      features of the GTAP database, e.g., changes in labels used.

  8.  The routines is this programme report a lot of information about
      the 'structure' of the GTAP database; this is important because
      it allows us to better understand the tranasction relationships.

  9.  USERS OF THE GTAP DATABASE MUST MAKE DECISIONS ABOUT HOW THEY
      CHOOSE TO ADDRESS THE IMPLICATIONS OF THESE ASPECTS OF THE
      DATABASE IF THEY WISH TO USE THE GTAP DATABASE. SOME CHOICES
      RELATE TO THE DATA AND SOME TO THE MODEL AND SOFTWARE.

         ############ OUR DECISIONS RE THE DATA ##############

   1.  Use the SAM representation of the GTAP database produced by
       the GTAPAgg routine; this SAM uses the system devised for GTAP
       Technical Paper 22 (the original version is available at
       www.gtap.agecon.purdue.edu/resources/res_display.asp?RecordID=1645).
       A revised and, slightly updated, version is available at
       http://cgemod.org.uk/tech_pap.html and is included in the
       GAMS library).
   2.  The option to use accounting identities to check the database
       is too valuable to discard (we also use these identities in our
       models).
   3.  'Small' TVs that create samll shares are 'problemmatic' when
       using functional forms that are standard in CGE models (CES, CET,
       LES, translog, etc), irrespective of the preferred solution
       method.
   4.  Some truncation of the non zero elements in the GTAP SAM is
       justified, because by definition there are large numbers of
       'non zero zeros', BUT it is not possible to determine which
       'non zero zeros' represent non transactions.
   5.  It is more efficient to resolve all data issues once; hence
       we choose to convert all GTAP data from HAR to GDX format once
       and at the same time truncate the non zero elements and FORCE
       the resultant SAM to satisfy the requisite accounting identities.
   6.  The imposition of the requisite accounting identities is achieved
       manually; the choice to 'balance' the SAM manually, rather than
       by, say, RAS, was largely taken to avoid creating new
       'small' transactions, but also to avoid proportionately large
       changes in tax and/or subsidy rates.
   7.  The trade margin accounts do not 'balance' and are 'tricky' to
       resolve using only within region data; hence we create a dummy
       region, 'GLOBE', that supplies and demands all margin services.
       This region is used in our models and is implicit in the GTAP
       model.
   8.  The whole of the GTAP database is transformed into a
       transactions SAM and a series of linked satellite accounts using
       a common set of account labels.
   9.  We provide two methods to generate aggregations of
       the SAMs created by this programme: (a) SAMGator, which is
       a MS Excel VBA programme, and (b) a GAMS programme
       - glb_12_aggr.gms - together with Excel workbooks

$offtext