* DECLARING, ASSIGNING AND CHECKING THE GTAP SAM

Parameter

* GTAP SAM

 SAM_gtp(samac,samac,kk)    GTAP version of global SAM

* BASIC Global SAM

 SAMG(ss,ss,kk)       Social accounting matrices for regions k

 FACTUSE(ss,ss,kk)    Factuse data for GLOBE SAM

* Other parameters

 DIFFTOT(*,kk)        Check on difference in region column and row totals
 BIGDIFFTOT(*,kk)     BIG (>1.0) difference in region column and row totals
 LRGDIFFTOT(*,kk)     LARGE (>0.01) difference in region column and row totals
 SUMDIFFTOT(kk)       Sum of differences in region row and column totals
 DIFFPER(*,kk)        Percentage differences in region column and row totals
 BIGDIFFPER(*,kk)     BIG (>0.01) Percentage diffs in region column and row totals

 DIFTOTPERCNT(step,case)  Counts of big total and percentage differences

   ;


*############## 7. LOADING DATA FOR GTAP SAM #############################

* Data are read in from a *.gdx file

$GDXIN data\GTAPsam.gdx

$LOAD SAM_gtp = SAM

$GDXIN


* Checking the GTAP SAM

*$INCLUDE include\chk_sam_gtp.inc


*###### Initialising SAMG from SAM_gtp
* This needs to be run in a LOOP over kkn

Loop(kkn,
 SAMG(ss,ssp,kkn)  =  SUM[(samac,samacp)
                        ${map_ss_samac(ss,samac)
                          $map_ss_samac(ssp,samacp)},
                            SAM_gtp(samac,samacp,kkn)] ;

 ) ;

Parameter
 SAMG_gtp(ss,ss,kk)  GTAP SAM ;

 SAMG_gtp(ss,ssp,kk)  = SAMG(ss,ssp,kk) ;

* Deleting the GTAP SAM

 SAM_gtp(samac,samacp,kkn) = 0.0 ;


*#### Rounding the Global SAM to 6 Decimal Places
* The GTAP database only records data to 6 decimal places

 SAMG(ss,ssp,kk)      = ROUND(SAMG(ss,ssp,kk),6) ;


*############## 10. CHECKING THE GLOBAL SAM ###########################
$ontext
 This checking of the Global SAM is important.

 The definition of 'errors' in the GTAP database is likely to differ
   according to the perspective of the user, e.g., small differences MAY
   NOT be an issue for some users/software.

 The approach here is to report absolute and proportionate differences
   across a range of cases.
$offtext

*#### Checking that Exports fob equal Imports fob
* This check is critical since it impacts upon all subsequent routines
* All entries in TradeCHK must be ZERO

* TRADECAL

Parameter
 Exports(mmc,ww,rr)    Exports of commod mmc to region ww by region rr
 Exports2(mmc,kk,rr)   Exports of commod mmc to region kk by region rr
 Exports3(mmc,kk,ww)   Exports of commod mmc to region kk by region ww

 Imports1(rr,mmc,kk)   Imports from region rr of commod mmc by region kk
 Imports2(rr,mmc,ww)   Imports from region rr of commod mmc by region ww

 TradeCHK_base(mmc,ww,rr)   Difference between imports and exports in GTAP SAM

 TradeCHK_SAMG(mmc,ww,kk)   Difference between imports and exports in SAMG final

 TraderrorCNT_base          Count on errors between Imports and exports fob
 TraderrorCNT_samg          Count on errors between Imports and exports fob

 ;

 Exports(mmc,ww,rr)  = SUM((ddc,kk)
                        $(map_mmc_ddc(mmc,ddc)
                         $map_rr_kk(rr,kk)),
                          SAMG(ddc,ww,kk)) ;

 Exports2(mmc,kk,rr) = SUM(ww
                        $map_kk_ww(kk,ww),
                         Exports(mmc,ww,rr)) ;

 Exports3(mmc,kk,ww) = SUM(rr
                        $map_ww_rr(ww,rr),
                          Exports2(mmc,kk,rr)) ;

 Imports1(rr,mmc,kk) = SUM(ww
                       $map_rr_ww(rr,ww),
                       SAMG(ww,mmc,kk)) ;

 Imports2(rr,mmc,ww) = SUM(kk
                       $map_ww_kk(ww,kk),
                       Imports1(rr,mmc,kk)) ;

 SAMG(ww,mmc,kk)     = Exports3(mmc,kk,ww) ;

 TradeCHK_base(mmc,ww,rr) = Exports(mmc,ww,rr) - Imports2(rr,mmc,ww) ;

 TradeCHK_SAMG(mmc,ww,kk) =  SAMG(ww,mmc,kk) - Exports3(mmc,kk,ww) ;

 TraderrorCNT_base  = SUM((mmc,ww,rr)$(TradeCHK_base(mmc,ww,rr) > 0.0000000001), 1) ;
 TraderrorCNT_samg  = SUM((mmc,ww,kk)$(TradeCHK_SAMG(mmc,ww,kk) > 0.0000000001), 1) ;

option decimals = 8 ;

Display TraderrorCNT_base, TraderrorCNT_samg ;

 ABORT$(TraderrorCNT_samg GT 0.0)
         "IMPORTS fob and EXPORTS fob ARE NOT IDENTICAL" ;

option decimals = 3 ;

*#### Computing Account totals for Global SAMG by Region

 SAMG("ttotal",ssnp,kk)        = SUM(ssn,SAMG(ssn,ssnp,kk)) ;

 SAMG(ssn,"ttotal",kk)         = SUM(ssnp,SAMG(ssn,ssnp,kk)) ;


$INCLUDE include\chk_samg.inc

* Identifying the MAX and MIN transactions for each Region

PARAMETER
 MAXTV(kk)        Max absolute value of transactions in SAM by region
 MINTV(kk)        Min absolute value of transactions in SAM by region ;

 MAXTV(kk)    = SMAX((ssn,ssnp),ABS (SAMG(ssn,ssnp,kk))) ;
 MINTV(kk)    = SMIN((ssn,ssnp)$SAMG(ssn,ssnp,kk),ABS (SAMG(ssn,ssnp,kk))) ;

*##### Unloading the GTAP SAMG to GDX

Execute_Unload  'GTP_output\SAMG_gtp.gdx',
                                    SAMG
                                    DIFFTOT
                                    BIGDIFFTOT
                                    LRGDIFFTOT
                                    SUMDIFFTOT
                                    DIFFPER
                                    BIGDIFFPER
                                    DIFTOTPERCNT
 ;






